<?php

namespace Controller;

use Zeedhi\Framework\DataSource\Manager;
use Service\DeleteCascadeService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Goals extends Crud {

    protected $dataSourceName = 'goals';
    protected $goalsService;
    protected $goalsNotificationsService;

    public function __construct(Manager $organizationMongoManager, DeleteCascadeService $deleteCascadeService,
        \Service\Goals $goalsService, \Service\GoalNotifications $goalsNotificationsService)
    {
        $this->goalsService = $goalsService;
        $this->goalsNotificationsService = $goalsNotificationsService;
        parent::__construct($organizationMongoManager, $deleteCascadeService);
    }

    public function removeGoals(DTO\Request $request, DTO\Response $response){
        $request = $this->buildDataSetIfRow($request);
        $dataSet = $request->getDataSet()->getRows();
        $goals = $dataSet[0]["goals"];
        $this->removeGoalsAndDependences($goals);
    }

    public function removeGoalsAndDependences($goals){
        foreach($goals as $goal){
            $goalId = $goal["_id"];
            $dependences = $this->goalsNotificationsService->getGoalNotificationByGoalId($goal["_id"]);
            $quantityDeleted = $this->goalsNotificationsService->delete($dependences);

            if(sizeof($dependences) == sizeof($quantityDeleted)){
                $this->goalsService->delete(array($goal));
            }
        }
        
    }

    protected function buildDataSetIfRow(DTO\Request $request) {
		if ($request instanceof DTO\Request\Row) {
			$dataSet = new DataSet($this->dataSourceName, array($request->getRow()));
			$request = new DTO\Request\DataSet($dataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
		}
		return $request;
	}
}