<?php
namespace Controller;

use Service\Traits\TResponse;
use Util\Utilities;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Zmart\DataSource\ZmartFilterCriteria;
use Zeedhi\Framework\DataSource\FilterCriteria;

class LogImportation {

    use TResponse;

	public function findNext(DTO\Request $request, DTO\Response $response)
	{
		try {
		    $params = $request->getParameters();

            /** @var \Service\LogImportation  $logImportation */
            $logImportation = InstanceManager::getInstance()->getService('\Service\LogImportation');
            //  Response
            //  $dynamicFilter = utf8_encode(base64_decode($dynamicFilter));
            Utilities::convertDynamicFilterToArray($params);
            $dataSet = Utilities::parseDataSourceZeedhiNext($logImportation->find($params), $logImportation->count($params));
            //  Pagination
            $dataSet['pagination']['page'] = array_key_exists('page', $params) ? intval($params['page']) : 1;
            $dataSet['pagination']['limit'] = array_key_exists('limit', $params) ? intval($params['limit']) : 99999;
            $this->sendResponse($dataSet, 200);
        } catch(\Exception $ex){
            $response->setError(new Response\Error($ex->getMessage(), $ex->getCode()));
        }
	}

    public function findFailNext(DTO\Request $request, DTO\Response $response)
    {
        try {
            $params = $request->getParameters();

            /** @var \Service\LogImportation  $logImportation */
            $logImportation = InstanceManager::getInstance()->getService('\Service\LogImportation');
            //  Response
            Utilities::convertDynamicFilterToArray($params);
            $dataResponse = Utilities::parseDataSourceZeedhiNext($logImportation->findFail($params), $logImportation->countFail($params));
            //  Pagination
            $dataResponse['pagination']['page'] = array_key_exists('page', $params) ? intval($params['page']) : 1;
            $dataResponse['pagination']['limit'] = array_key_exists('limit', $params) ? intval($params['limit']) : 99999;
            $this->sendResponse($dataResponse, 200);
        } catch(\Exception $ex){
            $response->setError(new Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function applyDateRangeFilter(&$conditions, $columnName){
        foreach ($conditions as &$condition) {
            if ($condition['columnName'] === $columnName && is_array($condition['value'])) {
                $condition['operator'] = "BETWEEN";
            }
        }
    }

    public function configImportationFail(DTO\Request $request, DTO\Response $response)
    {
        try {
            $params = $request->getParameters();
            $filter = Utilities::parseParamNextToZmartFilterCriteria('logImportationFail', $params);
            $conditions = $filter->getConditions();
            /** @var \Service\NotificationFail  $logImportation */
            $logImportation = InstanceManager::getInstance()->getService('\Service\NotificationFail');
            $dataSet = Utilities::parseDataSourceZeedhiNext($logImportation->findFail($conditions));
            $this->sendResponse($dataSet, 200);
        } catch(\Exception $ex){
            $response->setError(new Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function configImportationFailSave(DTO\Request\DataSet $request, DTO\Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows()[0];
            /** @var \Service\NotificationFail  $logImportation */
            $logImportation = InstanceManager::getInstance()->getService('\Service\NotificationFail');
            $saas = empty($rows['EMAIL_SAAS']) ? '' : $rows['EMAIL_SAAS'];
            $host = empty($rows['EMAIL_HOST']) ? '' : $rows['EMAIL_HOST'];
            $local = empty($rows['EMAIL_LOCAL']) ? '' : $rows['EMAIL_LOCAL'];
            $logImportation->saveConfigEmail($saas,$host,$local);
        } catch(\Exception $ex){
            $response->setError(new Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function notificationImportationFail(DTO\Request $request, DTO\Response $response)
    {
        try {
           // $conditions = $request->getFilterCriteria()->getConditions();
            /** @var \Service\LogImportation  $logImportation */
            $logImportation = InstanceManager::getInstance()->getService('\Service\LogImportation');
            $message =$logImportation->notificationImportationFail();
            $response->addMessage(new Message($message));

        } catch(\Exception $ex){
            $response->setError(new Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

	public function importLogImportation(DTO\Request\Filter $request, DTO\Response $response)
	{
		try {
            /** @var \Service\LogImportation  $logImportation */
            $logImportation = InstanceManager::getInstance()->getService('\Service\LogImportation');
            $logImportation->importLogImportation();
        } catch(\Exception $ex){
            $response->setError(new Response\Error($ex->getMessage(), $ex->getCode()));
        }
	}


}
